diff mbox

[U-Boot] ARM: atmel: add at91sam9g20ek_2mmc nand boot support

Message ID 1359510206-26447-1-git-send-email-voice.shen@atmel.com
State Accepted, archived
Delegated to: Andreas Bießmann
Headers show

Commit Message

Bo Shen Jan. 30, 2013, 1:43 a.m. UTC
Add at91sam9g20_2mmc nand boot support. on this board, there is no
dataflash, so disable it

change one commet for at91sam9g20ek board

Signed-off-by: Bo Shen <voice.shen@atmel.com>
---
 board/atmel/at91sam9260ek/at91sam9260ek.c |    7 ++++++-
 boards.cfg                                |    1 +
 include/configs/at91sam9260ek.h           |    2 ++
 3 files changed, 9 insertions(+), 1 deletion(-)

Comments

Bo Shen Feb. 18, 2013, 3:09 a.m. UTC | #1
Hi Andreas,

On 01/30/2013 09:43 AM, Bo Shen wrote:
> Add at91sam9g20_2mmc nand boot support. on this board, there is no
> dataflash, so disable it
>
> change one commet for at91sam9g20ek board
>
> Signed-off-by: Bo Shen<voice.shen@atmel.com>
> ---
>   board/atmel/at91sam9260ek/at91sam9260ek.c |    7 ++++++-
>   boards.cfg                                |    1 +
>   include/configs/at91sam9260ek.h           |    2 ++
>   3 files changed, 9 insertions(+), 1 deletion(-)

ping?

> diff --git a/board/atmel/at91sam9260ek/at91sam9260ek.c b/board/atmel/at91sam9260ek/at91sam9260ek.c
> index 2555672..3aa394a 100644
> --- a/board/atmel/at91sam9260ek/at91sam9260ek.c
> +++ b/board/atmel/at91sam9260ek/at91sam9260ek.c
> @@ -157,13 +157,18 @@ int board_early_init_f(void)
>
>   int board_init(void)
>   {
> +#ifdef CONFIG_AT91SAM9G20EK_2MMC
> +	/* arch number of AT91SAM9G20EK_2MMC-Board */
> +	gd->bd->bi_arch_number = MACH_TYPE_AT91SAM9G20EK_2MMC;
> +#else
>   #ifdef CONFIG_AT91SAM9G20EK
> -	/* arch number of AT91SAM9260EK-Board */
> +	/* arch number of AT91SAM9G20EK-Board */
>   	gd->bd->bi_arch_number = MACH_TYPE_AT91SAM9G20EK;
>   #else
>   	/* arch number of AT91SAM9260EK-Board */
>   	gd->bd->bi_arch_number = MACH_TYPE_AT91SAM9260EK;
>   #endif
> +#endif
>   	/* adress of boot parameters */
>   	gd->bd->bi_boot_params = CONFIG_SYS_SDRAM_BASE + 0x100;
>
> diff --git a/boards.cfg b/boards.cfg
> index e4b0d44..fa863dc 100644
> --- a/boards.cfg
> +++ b/boards.cfg
> @@ -95,6 +95,7 @@ at91sam9g10ek_nandflash      arm         arm926ejs   at91sam9261ek       atmel
>   at91sam9g20ek_dataflash_cs0  arm         arm926ejs   at91sam9260ek       atmel          at91        at91sam9260ek:AT91SAM9G20,SYS_USE_DATAFLASH_CS0
>   at91sam9g20ek_dataflash_cs1  arm         arm926ejs   at91sam9260ek       atmel          at91        at91sam9260ek:AT91SAM9G20,SYS_USE_DATAFLASH_CS1
>   at91sam9g20ek_nandflash      arm         arm926ejs   at91sam9260ek       atmel          at91        at91sam9260ek:AT91SAM9G20,SYS_USE_NANDFLASH
> +at91sam9g20ek_2mmc_nandflash arm         arm926ejs   at91sam9260ek       atmel          at91        at91sam9260ek:AT91SAM9G20,AT91SAM9G20EK_2MMC,SYS_USE_NANDFLASH
>   at91sam9m10g45ek_nandflash   arm         arm926ejs   at91sam9m10g45ek    atmel          at91        at91sam9m10g45ek:AT91SAM9M10G45,SYS_USE_NANDFLASH
>   at91sam9rlek_dataflash       arm         arm926ejs   at91sam9rlek        atmel          at91        at91sam9rlek:AT91SAM9RL,SYS_USE_DATAFLASH
>   at91sam9rlek_nandflash       arm         arm926ejs   at91sam9rlek        atmel          at91        at91sam9rlek:AT91SAM9RL,SYS_USE_NANDFLASH
> diff --git a/include/configs/at91sam9260ek.h b/include/configs/at91sam9260ek.h
> index f921fac..02696b3 100644
> --- a/include/configs/at91sam9260ek.h
> +++ b/include/configs/at91sam9260ek.h
> @@ -126,6 +126,7 @@
>   #endif
>
>   /* DataFlash */
> +#ifndef CONFIG_AT91SAM9G20EK_2MMC
>   #define CONFIG_ATMEL_DATAFLASH_SPI
>   #define CONFIG_HAS_DATAFLASH		1
>   #define CONFIG_SYS_SPI_WRITE_TOUT		(5*CONFIG_SYS_HZ)
> @@ -133,6 +134,7 @@
>   #define CONFIG_SYS_DATAFLASH_LOGIC_ADDR_CS0	0xC0000000	/* CS0 */
>   #define CONFIG_SYS_DATAFLASH_LOGIC_ADDR_CS1	0xD0000000	/* CS1 */
>   #define AT91_SPI_CLK			15000000
> +#endif
>
>   #ifdef CONFIG_AT91SAM9G20EK
>   #define DATAFLASH_TCSS			(0x22<<  16)
Andreas Bießmann Feb. 19, 2013, 11:13 a.m. UTC | #2
Dear Bo Shen,

> Add at91sam9g20_2mmc nand boot support. on this board, there is no
> dataflash, so disable it
> 
> change one commet for at91sam9g20ek board
> 
> Signed-off-by: Bo Shen <voice.shen@atmel.com>
> 
> ---
> board/atmel/at91sam9260ek/at91sam9260ek.c |    7 ++++++-
>  boards.cfg                                |    1 +
>  include/configs/at91sam9260ek.h           |    2 ++
>  3 files changed, 9 insertions(+), 1 deletion(-)

applied to u-boot-atmel/master, thanks!

Best regards

Andreas Bießmann
diff --git a/boards.cfg b/boards.cfg
index e4b0d44..fa863dc 100644
--- a/boards.cfg
+++ b/boards.cfg
@@ -95,6 +95,7 @@  at91sam9g10ek_nandflash      arm         arm926ejs   at91sam9261ek       atmel
 at91sam9g20ek_dataflash_cs0  arm         arm926ejs   at91sam9260ek       atmel          at91        at91sam9260ek:AT91SAM9G20,SYS_USE_DATAFLASH_CS0
 at91sam9g20ek_dataflash_cs1  arm         arm926ejs   at91sam9260ek       atmel          at91        at91sam9260ek:AT91SAM9G20,SYS_USE_DATAFLASH_CS1
 at91sam9g20ek_nandflash      arm         arm926ejs   at91sam9260ek       atmel          at91        at91sam9260ek:AT91SAM9G20,SYS_USE_NANDFLASH
+at91sam9g20ek_2mmc_nandflash arm         arm926ejs   at91sam9260ek       atmel          at91        at91sam9260ek:AT91SAM9G20,AT91SAM9G20EK_2MMC,SYS_USE_NANDFLASH
 at91sam9m10g45ek_nandflash   arm         arm926ejs   at91sam9m10g45ek    atmel          at91        at91sam9m10g45ek:AT91SAM9M10G45,SYS_USE_NANDFLASH
 at91sam9rlek_dataflash       arm         arm926ejs   at91sam9rlek        atmel          at91        at91sam9rlek:AT91SAM9RL,SYS_USE_DATAFLASH
 at91sam9rlek_nandflash       arm         arm926ejs   at91sam9rlek        atmel          at91        at91sam9rlek:AT91SAM9RL,SYS_USE_NANDFLASH
diff --git a/include/configs/at91sam9260ek.h b/include/configs/at91sam9260ek.h
index f921fac..02696b3 100644
--- a/include/configs/at91sam9260ek.h
+++ b/include/configs/at91sam9260ek.h
@@ -126,6 +126,7 @@ 
 #endif
 
 /* DataFlash */
+#ifndef CONFIG_AT91SAM9G20EK_2MMC
 #define CONFIG_ATMEL_DATAFLASH_SPI
 #define CONFIG_HAS_DATAFLASH		1
 #define CONFIG_SYS_SPI_WRITE_TOUT		(5*CONFIG_SYS_HZ)
@@ -133,6 +134,7 @@ 
 #define CONFIG_SYS_DATAFLASH_LOGIC_ADDR_CS0	0xC0000000	/* CS0 */
 #define CONFIG_SYS_DATAFLASH_LOGIC_ADDR_CS1	0xD0000000	/* CS1 */
 #define AT91_SPI_CLK			15000000
+#endif
 
 #ifdef CONFIG_AT91SAM9G20EK
 #define DATAFLASH_TCSS			(0x22 << 16)
diff mbox

Patch

diff --git a/board/atmel/at91sam9260ek/at91sam9260ek.c b/board/atmel/at91sam9260ek/at91sam9260ek.c
index 2555672..3aa394a 100644
--- a/board/atmel/at91sam9260ek/at91sam9260ek.c
+++ b/board/atmel/at91sam9260ek/at91sam9260ek.c
@@ -157,13 +157,18 @@  int board_early_init_f(void)
 
 int board_init(void)
 {
+#ifdef CONFIG_AT91SAM9G20EK_2MMC
+	/* arch number of AT91SAM9G20EK_2MMC-Board */
+	gd->bd->bi_arch_number = MACH_TYPE_AT91SAM9G20EK_2MMC;
+#else
 #ifdef CONFIG_AT91SAM9G20EK
 	/* arch number of AT91SAM9260EK-Board */
 	gd->bd->bi_arch_number = MACH_TYPE_AT91SAM9G20EK;
 #else
 	/* arch number of AT91SAM9260EK-Board */
 	gd->bd->bi_arch_number = MACH_TYPE_AT91SAM9260EK;
 #endif
+#endif
 	/* adress of boot parameters */
 	gd->bd->bi_boot_params = CONFIG_SYS_SDRAM_BASE + 0x100;
 
@@ -157,13 +157,18 @@  int board_early_init_f(void)
 #ifdef CONFIG_AT91SAM9G20EK
-	/* arch number of AT91SAM9260EK-Board */
+	/* arch number of AT91SAM9G20EK-Board */
 	gd->bd->bi_arch_number = MACH_TYPE_AT91SAM9G20EK;
 #else